"""
This module contains all SoundTouchUris that should be implemented by a
BOSE device. They were taken from the following files:

>>> rootfs/opt/Bose/etc/HandCraftedWebServer-SoundTouch.xml
>>> rootfs/opt/Bose/etc/WebServer-SoundTouch.xml

"""

from boseapi.common.message import SoundTouchUri, SoundTouchUriScope, SoundTouchUriType


def list_uris() -> dict:
    """Returns a dict with all SoundTouchURIs

    :return: all uris mapped to their name
    :rtype: dict
    """
    values = {}
    for uri_name, uri in __dict__.items():
        if isinstance(uri, SoundTouchUri):
            values[uri_name] = uri
    return values


############################################################################################################
# URI definitions
############################################################################################################
AbortSoftwareUpdate              = SoundTouchUri("AbortSoftwareUpdate")
addGroup                         = SoundTouchUri("addGroup")
addStation                       = SoundTouchUri("addStation")
addStereoPair                    = SoundTouchUri("addStereoPair")
addWirelessProfile               = SoundTouchUri("addWirelessProfile")
addZoneSlave                     = SoundTouchUri("addZoneSlave")
art                              = SoundTouchUri("art")
balance                          = SoundTouchUri("balance")
bass                             = SoundTouchUri("bass")
bassCapabilities                 = SoundTouchUri("bassCapabilities")
bluetoothInfo                    = SoundTouchUri("bluetoothInfo")
bookmark                         = SoundTouchUri("bookmark")
cancelPairLightswitch            = SoundTouchUri("cancelPairLightswitch")
capabilities                     = SoundTouchUri("capabilities")
clearBluetoothPaired             = SoundTouchUri("clearBluetoothPaired")
clearPairedList                  = SoundTouchUri("clearPairedList")
clockDisplay                     = SoundTouchUri("clockDisplay")
clockTime                        = SoundTouchUri("clockTime")
criticalError                    = SoundTouchUri("criticalError", SoundTouchUriScope.OP_SCOPE_PRIVATE)
criticalErrorUpdate              = SoundTouchUri("criticalErrorUpdate", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
DSPMonoStereo                    = SoundTouchUri("DSPMonoStereo")
enterBluetoothPairing            = SoundTouchUri("enterBluetoothPairing")
enterPairingMode                 = SoundTouchUri("enterPairingMode")
errorNotification                = SoundTouchUri("errorNotification", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
factoryDefault                   = SoundTouchUri("factoryDefault", SoundTouchUriScope.OP_SCOPE_PRIVATE)
genreStations                    = SoundTouchUri("genreStations")
getActiveWirelessProfile         = SoundTouchUri("getActiveWirelessProfile")
getBCOReset                      = SoundTouchUri("getBCOReset")
getGroup                         = SoundTouchUri("getGroup")
getZone                          = SoundTouchUri("getZone")
groupUpdated                     = SoundTouchUri("groupUpdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
info                             = SoundTouchUri("info")
introspect                       = SoundTouchUri("introspect")
key                              = SoundTouchUri("key")
language                         = SoundTouchUri("language")
languageUpdated                  = SoundTouchUri("languageUpdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
listMediaServers                 = SoundTouchUri("listMediaServers")
lowPowerStandby                  = SoundTouchUri("lowPowerStandby")
LowPowerStandbyUpdate            = SoundTouchUri("LowPowerStandbyUpdate", SoundTouchUriScope.OP_SCOPE_PRIVATE, SoundTouchUriType.OP_TYPE_EVENT)
marge                            = SoundTouchUri("marge")
masterMsg                        = SoundTouchUri("masterMsg")
name                             = SoundTouchUri("name")
nameSource                       = SoundTouchUri("nameSource")
nameUpdated                      = SoundTouchUri("nameUpdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
navigate                         = SoundTouchUri("navigate")
netStats                         = SoundTouchUri("netStats")
networkInfo                      = SoundTouchUri("networkInfo")
notification                     = SoundTouchUri("notification")
nowPlaying                       = SoundTouchUri("nowPlaying")
nowPlayingUpdated                = SoundTouchUri("nowPlayingUpdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
nowSelection                     = SoundTouchUri("nowSelection")
nowSelectionUpdated              = SoundTouchUri("nowSelectionUpdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
pairLightswitch                  = SoundTouchUri("pairLightswitch")
pdo                              = SoundTouchUri("pdo")
performWirelessSiteSurvey        = SoundTouchUri("performWirelessSiteSurvey")
playbackRequest                  = SoundTouchUri("playbackRequest")
playNotification                 = SoundTouchUri("playNotification", SoundTouchUriScope.OP_SCOPE_PRIVATE)
powerManagement                  = SoundTouchUri("powerManagement")
powersaving                      = SoundTouchUri("powersaving")
presets                          = SoundTouchUri("presets")
presetsUpdated                   = SoundTouchUri("presetsUpdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
pushCustomerSupportInfoToMarge   = SoundTouchUri("pushCustomerSupportInfoToMarge")
recents                          = SoundTouchUri("recents")
recentsUpdated                   = SoundTouchUri("recentsUpdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
removeGroup                      = SoundTouchUri("removeGroup")
removeMusicServiceAccount        = SoundTouchUri("removeMusicServiceAccount")
removePreset                     = SoundTouchUri("removePreset")
removeStation                    = SoundTouchUri("removeStation")
removeStereoPair                 = SoundTouchUri("removeStereoPair")
removeZoneSlave                  = SoundTouchUri("removeZoneSlave")
requestToken                     = SoundTouchUri("requestToken")
search                           = SoundTouchUri("search")
searchStation                    = SoundTouchUri("searchStation")
select                           = SoundTouchUri("select")
selectLastSoundTouchSource       = SoundTouchUri("selectLastSoundTouchSource")
selectLastSource                 = SoundTouchUri("selectLastSource")
selectLastWiFiSource             = SoundTouchUri("selectLastWiFiSource")
selectLocalSource                = SoundTouchUri("selectLocalSource")
selectPreset                     = SoundTouchUri("selectPreset")
serviceAvailability              = SoundTouchUri("serviceAvailability")
services                         = SoundTouchUri("services")
setBCOReset                      = SoundTouchUri("setBCOReset")
setComponentSoftwareVersion      = SoundTouchUri("setComponentSoftwareVersion", SoundTouchUriScope.OP_SCOPE_PRIVATE)
setMargeAccount                  = SoundTouchUri("setMargeAccount")
setMusicServiceAccount           = SoundTouchUri("setMusicServiceAccount")
setMusicServiceOAuthAccount      = SoundTouchUri("setMusicServiceOAuthAccount")
setPairedStatus                  = SoundTouchUri("setPairedStatus")
setPairingStatus                 = SoundTouchUri("setPairingStatus")
setPower                         = SoundTouchUri("setPower")
setProductSerialNumber           = SoundTouchUri("setProductSerialNumber", SoundTouchUriScope.OP_SCOPE_PRIVATE)
setProductSoftwareVersion        = SoundTouchUri("setProductSoftwareVersion", SoundTouchUriScope.OP_SCOPE_PRIVATE)
setup                            = SoundTouchUri("setup")
setWiFiRadio                     = SoundTouchUri("setWiFiRadio", SoundTouchUriScope.OP_SCOPE_PRIVATE)
setZone                          = SoundTouchUri("setZone")
slaveMsg                         = SoundTouchUri("slaveMsg")
SoftwareUpdateExit               = SoundTouchUri("SoftwareUpdateExit")
soundTouchConfigurationStatus    = SoundTouchUri("soundTouchConfigurationStatus")
soundTouchConfigurationUpdated   = SoundTouchUri("soundTouchConfigurationUpdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
sourceDiscoveryStatus            = SoundTouchUri("sourceDiscoveryStatus")
sources                          = SoundTouchUri("sources")
sourcesUpdated                   = SoundTouchUri("sourcesUpdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
speaker                          = SoundTouchUri("speaker")
standby                          = SoundTouchUri("standby")
StartSoftwareUpdate              = SoundTouchUri("StartSoftwareUpdate")
stationInfo                      = SoundTouchUri("stationInfo")
storePreset                      = SoundTouchUri("storePreset")
supportedURLs                    = SoundTouchUri("supportedURLs")
swUpdateAbort                    = SoundTouchUri("swUpdateAbort")
swUpdateCheck                    = SoundTouchUri("swUpdateCheck")
swUpdateQuery                    = SoundTouchUri("swUpdateQuery")
swUpdateStart                    = SoundTouchUri("swUpdateStart")
swUpdateStatusUpdated            = SoundTouchUri("swUpdateStatusUpdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
systemtimeout                    = SoundTouchUri("systemtimeout")
test                             = SoundTouchUri("test")
testCommandBA                    = SoundTouchUri("testCommandBA", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
testCommandSU                    = SoundTouchUri("testCommandSU", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
trackInfo                        = SoundTouchUri("trackInfo")
updateGroup                      = SoundTouchUri("updateGroup")
userActivity                     = SoundTouchUri("userActivity", SoundTouchUriScope.OP_SCOPE_PRIVATE)
userPlayControl                  = SoundTouchUri("userPlayControl")
userRating                       = SoundTouchUri("userRating")
userTrackControl                 = SoundTouchUri("userTrackControl")
volume                           = SoundTouchUri("volume")
volumeupdated                    = SoundTouchUri("volumeupdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
zoneUpdated                      = SoundTouchUri("zoneUpdated", uri_type=SoundTouchUriType.OP_TYPE_EVENT)
audiodspcontrols                 = SoundTouchUri("audiodspcontrols")
audiospeakerattributeandsetting  = SoundTouchUri("audiospeakerattributeandsetting")
productcechdmicontrol            = SoundTouchUri("productcechdmicontrol")
producthdmiassignmentcontrols    = SoundTouchUri("producthdmiassignmentcontrols")
audioproducttonecontrols         = SoundTouchUri("audioproducttonecontrols")
audioproductlevelcontrols        = SoundTouchUri("audioproductlevelcontrols")
systemtimeoutcontrol             = SoundTouchUri("systemtimeoutcontrol")
rebroadcastlatencymode           = SoundTouchUri("rebroadcastlatencymode")
